@@ -1,11 +1,12 @@
 package AnyEvent::DateTime::Cron;
 
+
 use warnings;
 use strict;
 use DateTime();
 use DateTime::Event::Cron();
 use AnyEvent();
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 #===================================
 sub new {
@@ -34,7 +35,7 @@ sub add {
                 last;
             }
             die "Unknown param '$key'"
-                unless $key =~ /^(name|single)$/;
+                unless $key =~ /^(name|single|time_zone)$/;
             $params{$key} = shift @args;
         }
         die "No callback found for cron entry '$cron'"
@@ -124,7 +125,14 @@ sub _schedule {
 
     for my $job (@_) {
         my $name       = $job->{name};
+		my $time_zone  = $job->{time_zone};
+
+        $now->set_time_zone($time_zone) if $time_zone;
+
         my $next_run   = $job->{event}->next($now);
+
+        $next_run->set_time_zone($time_zone) if $time_zone;
+
         my $next_epoch = $next_run->epoch;
         my $delay      = $next_epoch - $now_epoch;
 
@@ -185,7 +193,7 @@ AnyEvent::DateTime::Cron - AnyEvent crontab with DateTime::Event::Cron
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -241,6 +249,8 @@ C<ID> is used instead.
 The C<single> parameter, if C<true>, will only allow a single instance of
 a job to run at any one time.
 
+The C<time_zone> parameter will set the time_zone for any DateTime objects used.
+
 New jobs can be added before running, or while running.
 
 See L</"CALLBACKS"> for more.
@@ -309,15 +319,13 @@ until your job has completed:
 Callbacks are called inside an C<eval> so if they throw an error, they
 will warn, but won't cause the cron loop to exit.
 
-1;
-
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Clinton Gormley.
+This software is copyright (c) 2013 by Clinton Gormley.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
